﻿;-----------------------------------------------------------------------
; Webcam_Snap_Camera.ahk
;-----------------------------------------------------------------------
; Script to select different virtual props when using Snap Camera with
; Webcam Photobooth
;
; Run Snap Camera and add the required lenses to favourites and set
; shortcut 1 to Ctrl+Alt+A, shortcut 2 to Ctrl+Alt+B etc.
; Also add Ctrl+Alt+O as a shortcut the Snap Camera settings to turn the lens on/off.
;
; Then edit the toolbarLeft, toolbarRight, toolbarTop and toolbarBottom settings
; below to define the position of the touchscreen actions to control the props
; and set numProps to the number of props.
; 
; Run this script and then run Webcam Photobooth and set the camera to "Snap Camera"
;
; If you need to change the hotkey assignments in Snap Camera you also need to edit
; the Send commands in the SendToSnapCamera(prop) function in this script. Use ! for Alt,
; ^ for Ctrl and + for Shift. e.g. to send Ctrl+L use Send ^l

; Type Ctrl+Alt+S to display a debug window show the position of the toolbar.
; Type Ctrl+S again to hide the debug window
;
; AutoHotKey is free and can be downloaded from:
; https://www.autohotkey.com
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
; 20190209 - initial version
; 20190212 - fixed an issue with passing mouse clicks through
; 20200210 - added Ctrl+Alt+S to show toolbar position and improved the sending
;            shortcut keys
;-----------------------------------------------------------------------

#SingleInstance force
#NoEnv
SendMode Input
SetWorkingDir %A_ScriptDir%
SetTitleMatchMode, 1
DetectHiddenText, On

; These settings place the toolbar at the bottom center of a 1920x1080 screen
; Please edit these settings if your screen has a different resolution or you want
; change the size and position of the toolbar
toolbarLeft := 810
toolbarRight := 1110
toolbarTop := 930
toolbarBottom := 1030

numProps := 2

toolbarWidth := toolbarRight - toolbarLeft
toolbarHeight := toolbarBottom - toolbarTop
spacing := toolbarWidth / (numProps + 1)
debugWindow := 0

; define the debug window
Gui +LastFound +AlwaysOnTop -Caption +ToolWindow
Gui, Color, FF0000
Gui, Font, s10
Gui, Add, Text, cWhite, Ctrl+Alt+S to hide
Gui, Font, s20
Gui, Add, Text, vMyText cWhite, XXXXXX YYYYYYY

#IfWinActive,Breeze Systems Photobooth -
LBUTTON::
MouseGetPos,x,y
WinGetTitle,Title,Breeze Systems Photobooth -
if Title contains \ready,\video_ready
{
	WinGetPos,WinX,WinY,WinW,WinH,Breeze Systems Photobooth -
	MouseGetPos,x,y
	if (x > toolbarLeft) and (x < toolbarRight) and (y > toolbarTop) and (y < toolbarBottom)
	{
		prop := Floor((x - toolbarLeft) / spacing)
		SendToSnapCamera(prop)
		;MsgBox Left button %x% %y% %toolbarWidth% %spacing% %prop%
		return
	}
}
; click not used to control props: pass it on to the active window
MouseClick,,%x%,%y%
return

; Send hotkey sequence to load different favourites in Snap Camera
; 0 -> Ctrl+Alt+o to turn lens off/on
; 1 -> Ctrl+Alt+a to select favourite #1
; 2 -> Ctrl+Alt+b to select favourite #2
; etc.
; Edit the send commands to change the hotkey sequence. !=Alt, ^=Ctrl, +=Shift
; e.g. to send Ctrl+L use Send ^l
SendToSnapCamera(prop)
{
	ifWinNotExist,Snap Camera
	{
		MsgBox ERROR: Snap Camera is not running
		return
	}
	if prop = 0
	{
		Send ^!o
	}
	else if prop = 1
	{
		Send ^!a
	}
	else if prop = 2
	{
		Send ^!b
	}
	else if prop = 3
	{
		Send ^!c
	}
	else if prop = 4
	{
		Send ^!d
	}
	else if prop = 5
	{
		Send ^!e
	}
	else if prop = 6
	{
		Send ^!f
	}
	else if prop = 7
	{
		Send ^!g
	}
	else if prop = 8
	{
		Send ^!h
	}
	else if prop = 9
	{
		Send ^!i
	}
}

; Ctrl+Alt+S toggles the display of the debug window
!^S::
if debugWindow
{
	Gui, Hide
	SetTimer, UpdateOSD, Off
	debugWindow := 0
}
else
{
	SetTimer, UpdateOSD, 200
	Gui, Show, x%toolbarLeft% y%toolbarTop% w%toolbarWidth% h%toolbarHeight% NoActivate, ShowToolbar
	WinSet, Transparent, 100, ShowToolbar
	debugWindow := 1
}
return

; Function called by the mouse position display in the debug window
UpdateOSD:
MouseGetPos, MouseX, MouseY
GuiControl,, MyText, X%MouseX%, Y%MouseY%
return

